==> zio-aws-migrationhubrefactorspaces_2.12-5.17.157.2-sources.jar: zio/aws/migrationhubrefactorspaces/model/LambdaEndpointSummary.scala <==
package zio.aws.migrationhubrefactorspaces.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.migrationhubrefactorspaces.model.primitives.LambdaArn
import scala.jdk.CollectionConverters._
final case class LambdaEndpointSummary(arn: Option[LambdaArn] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary = {
    import LambdaEndpointSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
      .builder()
      .optionallyWith(
        arn.map(value => LambdaArn.unwrap(value): java.lang.String)
      )(_.arn)
      .build()
  }
  def asReadOnly
      : zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary.ReadOnly =
    zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary
      .wrap(buildAwsValue())
}
object LambdaEndpointSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary =
      zio.aws.migrationhubrefactorspaces.model
        .LambdaEndpointSummary(arn.map(value => value))
    def arn: Option[LambdaArn]
    def getArn: ZIO[Any, AwsError, LambdaArn] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
  ) extends zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary.ReadOnly {
    override val arn: Option[LambdaArn] = scala
      .Option(impl.arn())
      .map(value =>
        zio.aws.migrationhubrefactorspaces.model.primitives.LambdaArn(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
  ): zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-migrationhubrefactorspaces_2.12-5.17.202.1-sources.jar: zio/aws/migrationhubrefactorspaces/model/LambdaEndpointSummary.scala <==
package zio.aws.migrationhubrefactorspaces.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.migrationhubrefactorspaces.model.primitives.LambdaArn
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LambdaEndpointSummary(
    arn: Optional[LambdaArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary = {
    import LambdaEndpointSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
      .builder()
      .optionallyWith(
        arn.map(value => LambdaArn.unwrap(value): java.lang.String)
      )(_.arn)
      .build()
  }
  def asReadOnly
      : zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary.ReadOnly =
    zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary
      .wrap(buildAwsValue())
}
object LambdaEndpointSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary =
      zio.aws.migrationhubrefactorspaces.model
        .LambdaEndpointSummary(arn.map(value => value))
    def arn: Optional[LambdaArn]
    def getArn: ZIO[Any, AwsError, LambdaArn] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
  ) extends zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary.ReadOnly {
    override val arn: Optional[LambdaArn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        zio.aws.migrationhubrefactorspaces.model.primitives.LambdaArn(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.LambdaEndpointSummary
  ): zio.aws.migrationhubrefactorspaces.model.LambdaEndpointSummary.ReadOnly =
    new Wrapper(impl)
}
